==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/MergifyConditionalOperator.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) The Mergify conditional operators that can be used are: `or` and `and`.
 * <p>
 * Note: The number of nested conditions is limited to 3.
 * <p>
 * @see https://docs.mergify.io/conditions/#combining-conditions-with-operators
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.768Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.MergifyConditionalOperator")
@software.amazon.jsii.Jsii.Proxy(MergifyConditionalOperator.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface MergifyConditionalOperator extends software.amazon.jsii.JsiiSerializable {

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.Object> getAnd() {
        return null;
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.Object> getOr() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MergifyConditionalOperator}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MergifyConditionalOperator}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<MergifyConditionalOperator> {
        java.util.List<java.lang.Object> and;
        java.util.List<java.lang.Object> or;

        /**
         * Sets the value of {@link MergifyConditionalOperator#getAnd}
         * @param and the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder and(java.util.List<? extends java.lang.Object> and) {
            this.and = (java.util.List<java.lang.Object>)and;
            return this;
        }

        /**
         * Sets the value of {@link MergifyConditionalOperator#getOr}
         * @param or the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder or(java.util.List<? extends java.lang.Object> or) {
            this.or = (java.util.List<java.lang.Object>)or;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MergifyConditionalOperator}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public MergifyConditionalOperator build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MergifyConditionalOperator}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MergifyConditionalOperator {
        private final java.util.List<java.lang.Object> and;
        private final java.util.List<java.lang.Object> or;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.and = software.amazon.jsii.Kernel.get(this, "and", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.or = software.amazon.jsii.Kernel.get(this, "or", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.and = (java.util.List<java.lang.Object>)builder.and;
            this.or = (java.util.List<java.lang.Object>)builder.or;
        }

        @Override
        public final java.util.List<java.lang.Object> getAnd() {
            return this.and;
        }

        @Override
        public final java.util.List<java.lang.Object> getOr() {
            return this.or;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAnd() != null) {
                data.set("and", om.valueToTree(this.getAnd()));
            }
            if (this.getOr() != null) {
                data.set("or", om.valueToTree(this.getOr()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.MergifyConditionalOperator"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MergifyConditionalOperator.Jsii$Proxy that = (MergifyConditionalOperator.Jsii$Proxy) o;

            if (this.and != null ? !this.and.equals(that.and) : that.and != null) return false;
            return this.or != null ? this.or.equals(that.or) : that.or == null;
        }

        @Override
        public final int hashCode() {
            int result = this.and != null ? this.and.hashCode() : 0;
            result = 31 * result + (this.or != null ? this.or.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/MergifyConditionalOperator.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) The Mergify conditional operators that can be used are: <code>or</code> and <code>and</code>.
 * <p>
 * Note: The number of nested conditions is limited to 3.
 * <p>
 * @see <a href="https://docs.mergify.io/conditions/#combining-conditions-with-operators">https://docs.mergify.io/conditions/#combining-conditions-with-operators</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.433Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.MergifyConditionalOperator")
@software.amazon.jsii.Jsii.Proxy(MergifyConditionalOperator.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface MergifyConditionalOperator extends software.amazon.jsii.JsiiSerializable {

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.Object> getAnd() {
        return null;
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.Object> getOr() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MergifyConditionalOperator}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MergifyConditionalOperator}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<MergifyConditionalOperator> {
        java.util.List<java.lang.Object> and;
        java.util.List<java.lang.Object> or;

        /**
         * Sets the value of {@link MergifyConditionalOperator#getAnd}
         * @param and the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder and(java.util.List<? extends java.lang.Object> and) {
            this.and = (java.util.List<java.lang.Object>)and;
            return this;
        }

        /**
         * Sets the value of {@link MergifyConditionalOperator#getOr}
         * @param or the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder or(java.util.List<? extends java.lang.Object> or) {
            this.or = (java.util.List<java.lang.Object>)or;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MergifyConditionalOperator}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public MergifyConditionalOperator build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MergifyConditionalOperator}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MergifyConditionalOperator {
        private final java.util.List<java.lang.Object> and;
        private final java.util.List<java.lang.Object> or;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.and = software.amazon.jsii.Kernel.get(this, "and", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.or = software.amazon.jsii.Kernel.get(this, "or", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.and = (java.util.List<java.lang.Object>)builder.and;
            this.or = (java.util.List<java.lang.Object>)builder.or;
        }

        @Override
        public final java.util.List<java.lang.Object> getAnd() {
            return this.and;
        }

        @Override
        public final java.util.List<java.lang.Object> getOr() {
            return this.or;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAnd() != null) {
                data.set("and", om.valueToTree(this.getAnd()));
            }
            if (this.getOr() != null) {
                data.set("or", om.valueToTree(this.getOr()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.MergifyConditionalOperator"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MergifyConditionalOperator.Jsii$Proxy that = (MergifyConditionalOperator.Jsii$Proxy) o;

            if (this.and != null ? !this.and.equals(that.and) : that.and != null) return false;
            return this.or != null ? this.or.equals(that.or) : that.or == null;
        }

        @Override
        public final int hashCode() {
            int result = this.and != null ? this.and.hashCode() : 0;
            result = 31 * result + (this.or != null ? this.or.hashCode() : 0);
            return result;
        }
    }
}
